#!/bin/sh
# Copyright 2005 Slackintosh Linux
#
# Changelog: 
# adrian - 20050903 first version
#
#
( cd sbin ; rm -rf fdisk )
( cd sbin ; ln -sf mac-fdisk fdisk )

( cd sbin ; rm -rf fdisk.dos )
( cd sbin ; ln -sf dos-fdisk fdisk.dos )

( cd sbin ; rm -rf fdisk.mac )
( cd sbin ; ln -sf mac-fdisk fdisk.mac )


